/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, EventEmitter, Input, OnInit, Output } from "@angular/core";
import { CapabilityVersion } from "../../../../model/capability-version";
import { CapabilityRequestService } from "../../../../services/capability-request.service";
import { CapabilityRequest } from "../../../../model/capability-request";
import { JsonObject } from "@angular/compiler-cli/ngcc/src/packages/entry_point";

@Component({
  selector: "app-versions",
  templateUrl: "./versions.component.html",
  styleUrls: ["./versions.component.scss"],
})
export class VersionsComponent implements OnInit {
  @Input() capabilityRequest: CapabilityRequest;
  @Output() versionEvent = new EventEmitter<CapabilityVersion>();
  public capabilityVersions: Array<CapabilityVersion>;
  @Input() public selectedVersion: CapabilityVersion;

  constructor(private capabilityRequestService: CapabilityRequestService) {
    // this.getSpecificVersion(this.capabilityRequest.id, this.capabilityRequest.versions[this.capabilityRequest.versions.length-1].version_number);
  }

  ngOnInit(): void {}

  getVersion(): number {
    return this.selectedVersion.version_number;
  }

  getAllVersions(requestId: string) {
    const versionsObserver = {
      next: (request) => {
        this.capabilityVersions = request;
        console.log(this.capabilityVersions);
      },
      error: (error) => console.error("Error when retrieving capability versions:" + error),
    };
    this.capabilityRequestService.getAllVersions(requestId).subscribe(versionsObserver);
  }

  getSpecificVersion(request_id: string, version_id: number) {
    const specificVersionObserver = {
      next: (version) => {
        this.selectedVersion = version;
        this.versionEvent.emit(version);
      },
      error: (error) => console.error("Error when retrieving capability version:" + error),
    };
    this.capabilityRequestService
      .getSpecificVersion(request_id, version_id)
      .subscribe(specificVersionObserver);
  }

  /**
   * Check if JsonObject is empty
   * Taken from: https://stackoverflow.com/questions/679915/how-do-i-test-for-an-empty-javascript-object
   * @param obj  Object to be checked
   * @return boolean  true if object is empty; else false
   */
  isEmpty(obj: JsonObject): boolean {
    for (const prop in obj) {
      if (obj.hasOwnProperty(prop)) {
        return false;
      }
    }

    return true;
  }
}
